%define pypi_name	ply

Name:		python-%{pypi_name}
Version:	3.11
Release:	%mkrel 13
Summary:	Python Lex-Yacc
Group:		Development/Python
License:	BSD
URL:		http://www.dabeaz.com/ply/
Source:		%{pypi_source}
BuildArch:	noarch

%description
PLY is an implementation of lex and yacc parsing tools for Python.

In a nutshell, PLY is nothing more than a straightforward lex/yacc
implementation. Here is a list of its essential features:

 * It's implemented entirely in Python.
 * It uses LR-parsing which is reasonably efficient and well suited
   for larger grammars.
 * PLY provides most of the standard lex/yacc features including support
   for empty productions, precedence rules, error recovery, and support
   for ambiguous grammars.
 * PLY is straightforward to use and provides very extensive error checking.
 * PLY doesn't try to do anything more or less than provide the basic
   lex/yacc functionality. In other words, it's not a large parsing
   framework or a component of some larger system.

The original version of PLY was developed in 2001 for use in an
Introduction to Compilers course where students used it to build a
compiler for a simple Pascal-like language. Because of its use in an
instructional setting, a lot of work went into providing extensive
error checking. In addition, this experience was used to sort out
common usability problems. Since then, a variety of incremental
improvements have been made to the system. PLY-3.0 adds support for
Python 3.0 and gives PLY's internals a much needed overhaul.

%package -n	python3-%{pypi_name}
Summary:	Python 3 Lex-Yacc
Group:		Development/Python
BuildArch:	noarch
BuildRequires:  python3-devel
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n	python3-%{pypi_name}
PLY is an implementation of lex and yacc parsing tools for Python 3.

In a nutshell, PLY is nothing more than a straightforward lex/yacc
implementation. Here is a list of its essential features:

 * It's implemented entirely in Python.
 * It uses LR-parsing which is reasonably efficient and well suited
   for larger grammars.
 * PLY provides most of the standard lex/yacc features including support
   for empty productions, precedence rules, error recovery, and support
   for ambiguous grammars.
 * PLY is straightforward to use and provides very extensive error checking.
 * PLY doesn't try to do anything more or less than provide the basic
   lex/yacc functionality. In other words, it's not a large parsing
   framework or a component of some larger system.

The original version of PLY was developed in 2001 for use in an
Introduction to Compilers course where students used it to build a
compiler for a simple Pascal-like language. Because of its use in an
instructional setting, a lot of work went into providing extensive
error checking. In addition, this experience was used to sort out
common usability problems. Since then, a variety of incremental
improvements have been made to the system. PLY-3.0 adds support for
Python 3.0 and gives PLY's internals a much needed overhaul.

%prep
%setup -q -n %{pypi_name}-%{version}


# file-not-utf8
iconv -f iso8859-1 -t utf-8 CHANGES > CHANGES.conv && mv -f CHANGES.conv CHANGES

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ply

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc CHANGES README.md TODO
%doc doc/ example/ test/


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 3.11-13.mga10
+ Revision: 2236258
- Mageia 10 Mass Rebuild

* Sat Feb 22 2025 wally <wally> 3.11-12.mga10
+ Revision: 2150689
- rebuild for python3.13

* Sun Feb 11 2024 daviddavid <daviddavid> 3.11-11.mga10
+ Revision: 2040332
- rebuild again to remove old pkgs

* Wed Dec 13 2023 papoteur <papoteur> 3.11-10.mga10
+ Revision: 2017802
- rebuild for python 3.12

* Thu Dec 07 2023 wally <wally> 3.11-9.mga10
+ Revision: 2015173
- rebuild for py3.12

* Wed Mar 23 2022 umeabot <umeabot> 3.11-8.mga9
+ Revision: 1822257
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 3.11-7.mga9
+ Revision: 1772366
- rebuild for python3.10

* Mon Mar 15 2021 neoclust <neoclust> 3.11-6.mga9
+ Revision: 1703169
- Rebuild against python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 3.11-5.mga8
+ Revision: 1530722
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 3.11-4.mga8
+ Revision: 1437355
- rebuild for python3.8
- drop python2 support

* Sat Jan 05 2019 wally <wally> 3.11-3.mga7
+ Revision: 1349598
- rebuild for python3.7

* Thu Sep 20 2018 umeabot <umeabot> 3.11-2.mga7
+ Revision: 1289674
- Mageia 7 Mass Rebuild

* Sun Mar 25 2018 daviddavid <daviddavid> 3.11-1.mga7
+ Revision: 1212301
- new version: 3.11

* Wed Jan 10 2018 daviddavid <daviddavid> 3.10-1.mga7
+ Revision: 1192024
- new version: 3.10
- rename python-ply to python2-ply

* Fri Aug 04 2017 tv <tv> 3.8-3.mga7
+ Revision: 1134735
- rebuild for new python

* Sat Feb 20 2016 umeabot <umeabot> 3.8-2.mga6
+ Revision: 971132
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 daviddavid <daviddavid> 3.8-1.mga6
+ Revision: 889319
- new version: 3.8
- use new python macros
- update file list

* Thu Oct 08 2015 tv <tv> 3.4-10.mga6
+ Revision: 887481
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 3.4-9.mga5
+ Revision: 744921
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.4-8.mga5
+ Revision: 729323
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.4-7.mga5
+ Revision: 688219
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 3.4-6.mga5
+ Revision: 628892
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 3.4-5.mga4
+ Revision: 543966
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.4-4.mga4
+ Revision: 499121
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Sep 07 2013 marja <marja> 3.4-3.mga4
+ Revision: 475622
- add python3

* Sun Jan 13 2013 umeabot <umeabot> 3.4-2.mga3
+ Revision: 379279
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 31 2011 wally <wally> 3.4-1.mga2
+ Revision: 189234
- clean .spec
- imported package python-ply


* Wed Apr 20 2011 Paulo Andrade <pcpa@mandriva.com.br> 3.4-1mdv2011.0
+ Revision: 656088
- Update to latest upstream release

* Sat Oct 30 2010 Shlomi Fish <shlomif@mandriva.org> 3.3-2mdv2011.0
+ Revision: 590565
- New release - rebuild for python 2.7

* Sun Jan 10 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.3-1mdv2010.1
+ Revision: 489357
- new version

* Tue Jun 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.1-1mdv2010.0
+ Revision: 384253
- update to new version 3.1

* Sat Jan 03 2009 Funda Wang <fwang@mandriva.org> 2.5-2mdv2009.1
+ Revision: 323927
- clean spec

* Sat Nov 22 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.5-1mdv2009.1
+ Revision: 305847
- update to new version 2.5

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 2.3-4mdv2009.0
+ Revision: 259742
- rebuild

* Fri Jul 25 2008 Thierry Vignaud <tv@mandriva.org> 2.3-3mdv2009.0
+ Revision: 247588
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 2.3-1mdv2008.1
+ Revision: 136456
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Fri Feb 23 2007 Gaëtan Lehmann <glehmann@mandriva.org> 2.3-1mdv2007.0
+ Revision: 124895
- 2.3

* Thu Nov 30 2006 Gaëtan Lehmann <glehmann@mandriva.org> 2.2-1mdv2007.1
+ Revision: 88998
- sync sources
- 2.2
  drop patch 1
- 1.8
- Import python-ply

* Fri May 26 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 1.7-1mdv2007.0
- New release 1.7
- update url

* Wed Apr 26 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.5-3mdk
- Add BuildRequires
- use mkrel

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 1.5-2mdk
- Rebuild for new python

* Wed Sep 01 2004 Lenny Cartier <lenny@mandrakesoft.com> 1.5-1mdk
- from Gaetan Lehmann <glehmann@netcourrier.com> :
	- Create package from scratch for mandrake system

